<?php

namespace Drupal\conductor\Controller;

use Drupal\conductor\Service\ConductorConnector;
use Drupal\conductor\Service\ConductorHelper;
use Drupal\Core\Controller\ControllerBase;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\RequestStack;

/**
 * Content Guidance Endpoint.
 */
class ContentGuidance extends ControllerBase {

  /**
   * Conductor Connector.
   *
   * @var \Drupal\conductor\Service\ConductorConnector
   */
  protected $conductorConnector;

  /**
   * Conductor Helper.
   *
   * @var \Drupal\conductor\Service\ConductorHelper
   */
  protected $conductorHelper;

  /**
   * The current request.
   *
   * @var \Symfony\Component\HttpFoundation\Request
   */
  protected $request;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
        $container->get('conductor.connector'),
        $container->get('conductor.helper'),
        $container->get('request_stack')
      );
  }

  /**
   * Constructs a new object.
   *
   * @param \Drupal\conductor\Service\ConductorConnector $conductor_connector
   *   Conductor Connector service.
   * @param \Drupal\conductor\Service\ConductorHelper $conductor_helper
   *   Conductor Helper service.
   * @param \Symfony\Component\HttpFoundation\RequestStack $request_stack
   *   The request stack object.
   */
  public function __construct(
    ConductorConnector $conductor_connector,
    ConductorHelper $conductor_helper,
    RequestStack $request_stack,
  ) {
    $this->conductorConnector = $conductor_connector;
    $this->conductorHelper = $conductor_helper;
    $this->request = $request_stack->getCurrentRequest();
  }

  /**
   * Generate Content Guidance.
   */
  public function generateContentGuidance() {
    // Parameters.
    $api_key = $this->request->query->get('api_key') ?? '';
    $shared_secret = $this->request->query->get('shared_secret') ?? '';
    $url = $this->request->query->get('url') ?? '';
    $body_copy = $this->request->query->get('body_copy') ?? '';
    $topic = $this->request->query->get('topic') ?? '';
    $rank_source_id = $this->request->query->get('rank_source_id') ?? 1;
    // GET Account ID.
    $account = $this->conductorConnector->request('GET', '/accounts', [], $api_key, $shared_secret);
    $account_id = !empty($account[0]['accountId']) ? $account[0]['accountId'] : '';
    // GET Web Property ID.
    $web_property = $this->conductorConnector->request('GET', '/accounts/' . $account_id . '/web-properties', [], $api_key, $shared_secret);
    $web_property_id = !empty($web_property[0]['webPropertyId']) ? $web_property[0]['webPropertyId'] : '';
    // Construct content guidance recommendations.
    $request_id = $this->conductorHelper->fetchRequestId($account_id, $web_property_id, $topic, $rank_source_id, $url, $body_copy, $api_key, $shared_secret) ?? [];
    $output = $this->conductorHelper->fetchRecommendations($account_id, $request_id, $api_key, $shared_secret) ?? [];

    return new JsonResponse($output);
  }

}
