<?php

namespace Drupal\Tests\your_module\Functional;

use Drupal\Tests\BrowserTestBase;

/**
 * Tests the admin configuration form.
 *
 * @group conductor
 */
class ConductorConfigFormTest extends BrowserTestBase {

  /**
   * Modules to enable.
   *
   * @var array
   */
  protected static $modules = ['node', 'conductor'];


  /**
   * The default theme to use.
   *
   * @var string
   */
  protected $defaultTheme = 'stark';

  /**
   * Tests that the form is reachable.
   */
  public function testFormAccess(): void {
    $this->drupalLogin($this->drupalCreateUser(['administer conductor']));
    $this->drupalGet('/admin/config/development/conductor');
    $this->assertSession()->statusCodeEquals(200);
  }

  /**
   * Test form submission with random API key.
   *
   * @throws \Behat\Mink\Exception\ElementNotFoundException
   * @throws \Behat\Mink\Exception\ResponseTextException
   * @throws \Drupal\Core\Entity\EntityStorageException
   */
  public function testFormSubmissionFailsWithRandomApiKey(): void {
    $this->drupalLogin($this->drupalCreateUser(['administer conductor']));
    $this->drupalGet('/admin/config/development/conductor');

    $this->getSession()->getPage()->findField('api_key')->setValue('Sample API Key');
    $this->getSession()->getPage()->findField('shared_secret')->setValue('Sample shared secret');
    $this->getSession()->getPage()->pressButton('Save configuration');

    $this->assertSession()->pageTextContains('Unable to connect to Conductor API.');

  }

  /**
   * Tests logging is disabled by default.
   *
   * @throws \Behat\Mink\Exception\ElementNotFoundException
   */
  public function testLoggingDisabledByDefault(): void {
    $this->drupalLogin($this->drupalCreateUser(['administer conductor']));
    $this->drupalGet('/admin/config/development/conductor');
    $this->assertEquals('0', $this->getSession()->getPage()->findField('logging')->getValue());
  }

  /**
   * Test if config values are reflecting in form.
   *
   * @throws \Drupal\Core\Entity\EntityStorageException
   */
  public function testConfigSettingsMatchFormDefaultValues(): void {
    $config = \Drupal::configFactory()->getEditable('conductor.settings');
    $config->set('conductor.logging', '1');
    $config->set('conductor.api_key', 'Sample API key');
    $config->set('conductor.shared_secret', 'Sample shared secret');
    $config->save();

    $this->drupalLogin($this->drupalCreateUser(['administer conductor']));
    $this->drupalGet('/admin/config/development/conductor');

    $this->assertEquals('1', $this->getSession()->getPage()->findField('logging')->getValue());
    $this->assertEquals('Sample API key', $this->getSession()->getPage()->findField('api_key')->getValue());
    $this->assertEquals('Sample shared secret', $this->getSession()->getPage()->findField('shared_secret')->getValue());

  }

}
