<?php

namespace Drupal\Tests\conductor\Unit;

use Drupal\conductor\Service\ConductorConnector;
use Drupal\Tests\UnitTestCase;
use GuzzleHttp\Client;

/**
 * @coversDefaultClass \Drupal\conductor\Service\ConductorConnector
 * @group conductor
 */
class ConductorConnectorTest extends UnitTestCase {

  /**
   * Config Factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface|\PHPUnit\Framework\MockObject\MockObject
   */
  protected $configSettings;

  /**
   * Guzzle HTTP client.
   *
   * @var \GuzzleHttp\Client|\PHPUnit\Framework\MockObject\MockObject
   */
  protected $httpClient;

  /**
   * Logger.
   *
   * @var \Psr\Log\LoggerInterface|\PHPUnit\Framework\MockObject\MockObject
   */
  protected $logger;

  /**
   * Conductor Connector service.
   *
   * @var \Drupal\conductor\Service\ConductorConnector|\PHPUnit\Framework\MockObject\MockObject
   */
  protected $connectorService;

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();
    $this->httpClient = $this->createMock(Client::class);
    $this->logger = $this->createMock('\Psr\Log\LoggerInterface');
    $this->configSettings = $this->getConfigFactoryStub([
      'conductor.settings' => [
        'conductor' => [
          'api_key' => '',
          'shared_secret' => '',
        ],
      ],
    ]);
    $this->connectorService = new ConductorConnector($this->configSettings, $this->httpClient, $this->logger);
  }

  /**
   * Tests connection to account.
   */
  public function testConnection() {
    // Get account.
    $connect = $this->connectorService->request('GET', '/accounts', [], 'api_key', 'shared_secret');
    // Request will return an empty array unless provided a valid api key and
    // shared secret.
    $this->assertEmpty($connect);
  }

}
